===================================================
Ethereum -- Next generation cryptocurrency network
===================================================

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :alt: Join the chat at https://gitter.im/ethereum/pyethereum
   :target: https://gitter.im/ethereum/pyethereum?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

Ethereum Core Library
=====================

This is the Python core library of the Ethereum project.

For the python based command line client see:
https://github.com/ethereum/pyethapp


+-----------+------------------+------------------+--------------------+--------------------+
|           | Linux            | OSX              | Travis             | Coverage           |
+-----------+------------------+------------------+--------------------+--------------------+
| develop   | |Linux develop|  | |OSX develop|    | |Travis develop|   | |Coverage develop| |
+-----------+------------------+------------------+--------------------+--------------------+
| master    | |Linux master|   | |OSX master|     | |Travis master|    | |Coverage master|  |
+-----------+------------------+------------------+--------------------+--------------------+

Quickstart
-------------

Installation:
++++++++++++++


``git clone https://github.com/ethereum/pyethereum/``

``cd pyethereum``

``python setup.py install``



For developers
---------------

See our `developer notes <https://github.com/ethereum/pyethereum/wiki/Developer-Notes>`_


Licence
========
See LICENCE

`Ethereum <https://ethereum.org/>`_ is based on a design by Vitalik Buterin.

.. |Linux develop| image:: https://build.ethdev.com/buildstatusimage?builder=Linux%20PyEthereum%20develop
   :target: https://build.ethdev.com/builders/Linux%20PyEthereum%20develop/builds/-1
.. |OSX develop| image:: https://build.ethdev.com/buildstatusimage?builder=OSX%20PyEthereum%20develop
   :target: https://build.ethdev.com/builders/OSX%20PyEthereum%20develop/builds/-1
.. |Linux master| image:: https://build.ethdev.com/buildstatusimage?builder=Linux%20PyEthereum%20master
   :target: https://build.ethdev.com/builders/Linux%20PyEthereum%20master/builds/-1
.. |OSX master| image:: https://build.ethdev.com/buildstatusimage?builder=OSX%20PyEthereum%20master
   :target: https://build.ethdev.com/builders/OSX%20PyEthereum%20master/builds/-1

.. |Travis develop| image:: https://travis-ci.org/ethereum/pyethereum.png?branch=develop
   :target: https://travis-ci.org/ethereum/pyethereum
.. |Travis master| image:: https://travis-ci.org/ethereum/pyethereum.png?branch=master
   :target: https://travis-ci.org/ethereum/pyethereum
.. |Coverage develop| image:: https://coveralls.io/repos/ethereum/pyethereum/badge.png?branch=develop
   :target: https://coveralls.io/r/ethereum/pyethereum?branch=develop
.. |Coverage master| image:: https://coveralls.io/repos/ethereum/pyethereum/badge.png?branch=master
   :target: https://coveralls.io/r/ethereum/pyethereum?branch=master
